netapp_ontap.resources.security_audit API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.security_audit`

Copyright © 2020 NetApp Inc. All rights reserved.

## Overview

This API controls what is logged to the audit log files. All operations that make changes are always logged and cannot be disabled. The PATCH request updates administrative audit settings for GET requests. All fields are optional for a PATCH request. A GET request retrieves administrative audit settings for GET requests.

## Examples

### Retrieving administrative audit settings for GET requests

The following example shows the administrative audit settings for GET requests.

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecurityAudit

    with HostConnection(
        "<cluster-ip>", username="admin", password="password", verify=False
    ):
        resource = SecurityAudit()
        resource.get()
        print(resource)

Try it out

    SecurityAudit({"http": False, "cli": False, "ontapi": False})

### Updating administrative audit settings for GET requests

The following example updates the administrative audit settings for GET requests

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import SecurityAudit

    with HostConnection(
        "<cluster-ip>", username="admin", password="password", verify=False
    ):
        resource = SecurityAudit()
        resource.cli = False
        resource.http = True
        resource.ontapi = True
        resource.patch()

## Classes

`class SecurityAudit (*args, **kwargs)`

  Allows interaction with SecurityAudit objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get(self, **kwargs) -> NetAppResponse`

    Retrieves administrative audit settings for GET requests.

    ### Learn more

    - `DOC /security/audit`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  `def patch(self, hydrate: bool = False, poll: bool = True, poll_interval: typing.Union = None, poll_timeout: typing.Union = None, **kwargs) -> NetAppResponse`

    Updates administrative audit settings for GET requests. All of the fields are optional. An empty body will make no changes.

    ### Learn more

    - `DOC /security/audit`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
`class SecurityAuditSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the SecurityAudit object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `cli GET POST PATCH`

    Enable auditing of CLI GET Operations. Valid in PATCH

  `http GET POST PATCH`

    Enable auditing of HTTP GET Operations. Valid in PATCH

  `ontapi GET POST PATCH`

    Enable auditing of ONTAP API GET operations. Valid in PATCH